# crimjustsimpy
Tools for criminal justice simulation.

##Introduction
This module contains a few classes that can help with simulating
certain elements of the criminal justice system in the United States.

At present, it only simululates cases that have a probabilistic outcome at trial,
with an option to plea bargain that is solely a random choice. In the future,
I hope to add more realistic simulation of how both prosecutors and defendants
make plea bargaining decisions.